@@ -82,18 +82,7 @@
     if (dataset_type == "multiple" && calc_avg) {
       modnames <- attr(mdat, "data_info")[["modnames"]]
       uniq_modnames <- attr(mdat, "uniq_modnames")
-      if (eval_type == "mcc" || eval_type == "label") {
-        minval = -1.0
-        maxval = 1.0
-      } else if (eval_type == "score") {
-        minval = NA_real_
-        maxval = NA_real_
-      } else {
-        minval = 0.0
-        maxval = 1.0
-      }
-      avgcurves <- calc_avg_basic(pevals, modnames, uniq_modnames, cb_alpha,
-                                  minval, maxval)
+      avgcurves <- calc_avg_basic(pevals, modnames, uniq_modnames, cb_alpha)
     } else {
       avgcurves <- NA
     }
